package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.PersonnelManagement;

/**
 * 人员管理Mapper接口
 * 
 * @author ruoyi
 * @date 2024-02-28
 */
public interface PersonnelManagementMapper 
{
    /**
     * 查询人员管理
     * 
     * @param personneId 人员管理主键
     * @return 人员管理
     */
    public PersonnelManagement selectPersonnelManagementByPersonneId(Long personneId);

    /**
     * 查询人员管理列表
     * 
     * @param personnelManagement 人员管理
     * @return 人员管理集合
     */
    public List<PersonnelManagement> selectPersonnelManagementList(PersonnelManagement personnelManagement);

    /**
     * 新增人员管理
     * 
     * @param personnelManagement 人员管理
     * @return 结果
     */
    public int insertPersonnelManagement(PersonnelManagement personnelManagement);

    /**
     * 修改人员管理
     * 
     * @param personnelManagement 人员管理
     * @return 结果
     */
    public int updatePersonnelManagement(PersonnelManagement personnelManagement);

    /**
     * 删除人员管理
     * 
     * @param personneId 人员管理主键
     * @return 结果
     */
    public int deletePersonnelManagementByPersonneId(Long personneId);

    /**
     * 批量删除人员管理
     * 
     * @param personneIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePersonnelManagementByPersonneIds(Long[] personneIds);
}
